pub enum DataMode {
Words,
Bits,
All,
}Expand description
Read-out mode for bulk memory reads
This is primarily used with [Instrument::pick_one] to read a block
of memory values from the internal long process buffer. When Words
is selected only the 32 values that correspond to configured word channels
will be retrieved in ascending channel order. When Bits is selected
the 32 values that correspond to the configured bit channels will be
retrieved, again in ascending channel order. When All is selected all
raw values in ascending channel number are retrieved.
Variants