UpdateSelector

Struct UpdateSelector 

pub struct UpdateSelector { /* private fields */ }
Configure selector circuits

This command is used to manage the on-board selector circuits. Unlike the 32 generic I/Os selector circuits are exclusively output and they are typically used for managing transistor gates or other EN signals for ASICs.

Please note that this instruction only flips the outputs between high and low. Actual voltages for low and high levels should be adjusted by setting the SELL and SELH voltages respectively through a SetDAC instruction on the AUX DACs. This is typically done on the top-level through the [Instrument::config_aux_channels][crate::instrument::Instrument::config_aux_channels()] function by setting AuxDACFn.SELL and .SELH.

Instruction layout

       +--------+--------------+
       | OpCode | SelectorMask |
       +--------+--------------+
Words:     1         1

Implementations

Source

impl UpdateSelector

pub fn new(channels: &SelectorMask) -> Self

Create a new selector update instruction with the specified selector channel mask.

pub fn new_from_channels(chans: &[usize]) -> Result<Self, InstructionError>

Create a new selector update instructions with the specified selector channels pulled high.