Empty

Struct Empty 

pub struct Empty(/* private fields */);
An empty register, typically used to pad instructions to full length.

An Empty should never need to be invoked manually as empty instructions are added appropriately when an instruction is compiled.

Implementations

Source

impl Empty

pub fn new() -> Empty

Create a new empty register